/* This file is part of airuiplugin package *
 *
 * Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Suresh Chande <suresh.chande@nokia.com> and
 *          Vladimir Ushakov <vladimir.ushakov@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all
 * of this material requires the prior written consent of Nokia
 * Corporation. This material also contains confidential information
 * which may not be disclosed to others without the prior written
 * consent of Nokia.
 */

import QtQuick 1.0
import com.nokia.airui 1.0

GestureInterpreter {

    onEventReceived: {
        var objects = findGraphicsObjects()

        // Only perform the recognition if a specific page is visible
        var filtered = filterByType(objects, "NowPlayingPage")
        if (filtered.length == 0) return
        var nowPlaying = filtered[0]
        if (!nowPlaying.onDisplay) return

        var buttons = filterByType(objects, "MButton")
        var visibleButtons = new Array();
        for (var i = 0; i < buttons.length; i++) {
                if (buttons[i].onDisplay) visibleButtons.push(buttons[i])
        }

        // The way to distinguish the buttons is that they have no names
        // contrary to previous/menu buttons
        visibleButtons = filterByName(visibleButtons, "")

        var previous = findByIcon("icon-m-toolbar-mediacontrol-previous", visibleButtons)
        var play = findByIcon("icon-m-toolbar-mediacontrol-play", visibleButtons)
        if (play == undefined || play == null)
            play = findByIcon("icon-m-toolbar-mediacontrol-pause", visibleButtons)
        var next = findByIcon("icon-m-toolbar-mediacontrol-next", visibleButtons)

        switch(event) {
            case GestureInterpreter.Up:
            case GestureInterpreter.Left:
                    previous.click();
                    break;
            case GestureInterpreter.Down:
            case GestureInterpreter.Right:
                    next.click();
                    break;
            case GestureInterpreter.Press:
                    play.click();
                    break;
        }
    }

    function findByIcon(iconRegExp, buttons) {
        printString("matching: " + iconRegExp)
        for (var i = 0; i < buttons.length; i++) {
            var iconId = buttons[i].iconID
            if (iconId.match(iconRegExp) != null) {
                printString("Found match: " + iconId)
                return buttons[i]
            }
        }
        return null
    }
}
